@@ -3,12 +3,6 @@
 # scrub -std=... flag which conflicts with builds
 export CXXFLAGS=$(echo ${CXXFLAGS:-} | sed -E 's@\-std=[^ ]*@@g')
 
-# Increase CPUs for multiarch builds
-if [ "$(uname -m)" = "armv8" ] || [ "$(uname -m)" = "ppc64le" ]; then
-    echo "Using $(grep -c ^processor /proc/cpuinfo) CPUs"
-    CPU_COUNT=$(grep -c ^processor /proc/cpuinfo)
-fi
-
 if [ "$(uname)" = "Darwin" ]; then
     # unset macosx-version-min hardcoded in clang CPPFLAGS
     export CPPFLAGS="$(echo ${CPPFLAGS:-} | sed -E 's@\-mmacosx\-version\-min=[^ ]*@@g')"
@@ -24,23 +18,33 @@ echo "sysroot: ${CONDA_BUILD_SYSROOT:-unset}"
 # The without snapshot comes from the error in
 # https://github.com/nodejs/node/issues/4212.
 ./configure \
-    --prefix=$PREFIX \
+    --ninja \
+    --prefix=${PREFIX} \
     --without-snapshot \
     --without-node-snapshot \
+    --shared \
     --shared-libuv \
     --shared-openssl \
     --shared-zlib \
     --with-intl=system-icu
 
-# Decrease parallelism a bit as we will otherwise get out-of-memory problems
-# This is only necessary on Travis
-if [ "${TRAVIS}" = "true" ]; then
-  make -j1
+if [ "$(uname -m)" = "ppc64le" ]; then
+    # Decrease parallelism a bit as we will otherwise get out-of-memory problems
+    echo "Using $(grep -c ^processor /proc/cpuinfo) CPUs"
+    CPU_COUNT=$(grep -c ^processor /proc/cpuinfo)
+    CPU_COUNT=$((CPU_COUNT / 2))
+    ninja -C out/Release -j${CPU_COUNT}
 else
-  make -j${CPU_COUNT}
+    ninja -C out/Release
 fi
-make install > /dev/null
+
+python tools/install.py install ${PREFIX} ''
+cp out/Release/node $PREFIX/bin
 
 node -v
 npm version
 
+if [ "$(uname)" != "Darwin" ]; then
+  # Get rid of OSX specific files that confuse conda-build
+  rm -rf $PREFIX/lib/node_modules/npm/node_modules/term-size/vendor/macos/term-size
+fi
